#!/usr/bin/env python3

{% if global.license == "MIT" %}
# MIT License
#
{% endif %}
{% if global.license != "Apache2" %}
# Copyright (C) {{ global.year }} {{ global.organization }}
#
{% endif %}
{{ global.license_header }}

import sys
from testrunner import run


def testfunc(child):
    # put here the pexpect code that checks the output of the test application.
    pass


if __name__ == "__main__":
    sys.exit(run(testfunc))
